
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Panner.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvPanner.h>

// -------------------------------------------

xvPanner::xvPanner()
{
	alloc=FALSE;
}

// -------------------------------------------

xvPanner::xvPanner(String name, xvCore & parent, XtCallbackProc callback,
			Dimension sizeH, Dimension sizeW, Position InitX, Position InitY)
{
	init(name, parent, callback, sizeH, sizeW, InitX, InitY);
}

// -------------------------------------------

xvPanner::~xvPanner()
{
	if (alloc) XtDestroyWidget(w);
}

// -------------------------------------------

void xvPanner::init(String name, xvCore & parent, XtCallbackProc callback,
			Dimension sizeH, Dimension sizeW, Position InitX, Position InitY)
{
	w=XtVaCreateManagedWidget(name, pannerWidgetClass, parent.ID(),
		"canvasHeight", sizeH, "canvasWidth", sizeW,
		"sliderHeight", sizeH/10, "sliderWidth", sizeW/10,
		"sliderX", InitX, "sliderY", InitY,
		NULL);

	XtAddCallback(w, XtNreportCallback, callback, 0);
	alloc=TRUE;
}

// ------------------------------------------

void xvPanner::Where(Position *XPos, Position *YPos)
{
	XtVaGetValues(w, XtNsliderX, XPos, NULL);
	XtVaGetValues(w, XtNsliderY, YPos, NULL);
}

// -------------------------------------------

void xvPanner::SetSliderPosition(Position XPos, Position YPos)
{
	XtVaSetValues(w, XtNsliderX, XPos, XtNsliderY, YPos, NULL);
}

// -------------------------------------------

void xvPanner::SetSliderSize(Dimension sx, Dimension sy)
{
	XtVaSetValues(w, XtNsliderHeight, sy, XtNsliderWidth, sx, NULL);
}

// -------------------------------------------

void xvPanner::SetCanvasSize(Dimension sx, Dimension sy)
{
	XtVaSetValues(w, XtNcanvasWidth, sx, XtNcanvasHeight, sy, NULL);
}

// -------------------------------------------

void xvPanner::SetdefaultScale(Dimension sca)
{
	XtVaSetValues(w, XtNdefaultScale, sca, NULL);
}

// -------------------------------------------